from django.urls import resolve
from django.conf import settings

class AppAuthentication:
    def __init__(self, get_response):
        self.get_response = get_response
        # One-time configuration and initialization.

    def __call__(self, request):
        # Code to be executed for each request before
        # the view (and later middleware) are called.

        response = self.get_response(request)

        # Code to be executed for each request/response after
        # the view is called.

        return response

    def process_view(self, request, view_func, view_args, view_kwargs):
        app_name = view_func.__module__.split(".")[0].lower()
        # if not app_name.lower().startswith("django.contrib"):
        request.user_in_group = False
        if app_name in settings.DEVELOPER_INSTALLED_APPS:
            print(settings.DEVELOPER_INSTALLED_APPS)
            print(f" app name: {app_name}, request user: {request.user.username}")
            if (settings.ALLOW_ALL_SUPERUSER and request.user.is_superuser )or request.user.groups.filter(name=app_name).exists():
                request.user_in_group = True
        print(request.user_in_group)
        return None # Continue with view stuff
        


from django.core.management.base import BaseCommand, no_translations

from django.contrib.auth.models import Group

from django.conf import settings

import sys

class Command(BaseCommand):
    
    def handle(self, *args, **options):
        sys.stdout.write("\nResolving app groups")
        app_list = [app_name.lower() for app_name in settings.DEVELOPER_INSTALLED_APPS]
        for app_name in app_list:
            created = Group.objects.get_or_create(name=app_name)
            sys.stdout.write(f"\n{app_name}, new={created}")
        
        sys.stdout.write("\n")


from django.shortcuts import render
from django.views import View
from rest_framework.views import APIView
from rest_framework import authentication, permissions
from rest_framework import status
from django.http import HttpResponseForbidden
from django.http import HttpResponseForbidden
from django.http import JsonResponse

from django.shortcuts import render
from rest_framework.response import Response
# Create your views here.
from django.views import View
from django.http import HttpResponse

# Create your views here.

class APIAppAuthView(APIView):
    authentication_classes = [authentication.TokenAuthentication]    
    permission_classes = (permissions.IsAuthenticated,)    
    def dispatch(self, request, *args, **kwargs):
        if not request.user_in_group:
            return JsonResponse({}, status=status.HTTP_403_FORBIDDEN)
        else:
            return super(__class__,self).dispatch(request,*args, **kwargs) 

class AppAuthView(View):
    def dispatch(self, request, *args, **kwargs):
        print("APP AUTH")
        if not request.user_in_group:
            return HttpResponseForbidden()
        else:
            return super(__class__,self).dispatch(request,*args, **kwargs) 



from setuptools import (
    setup,
    find_packages,
)



setup(
    name='django-app-permissions',
    version='0.0.0',
    url='https://github.com/amp89/django-app-permissions',
    download_url="https://github.com/amp89/django-app-permissions/blob/master/dist/django-app-permissions-0.0.0.tar.gz",
    license='MIT',
    description='Automatic app level authentication for django apps using django',
    long_description=open('README.rst', 'r', encoding='utf-8').read(),
    author='Alex Peterson',
    author_email='contact@alexpeterson.tech',
    install_requires=[
        'django',
        'djangorestframework',
        'django-drf-advanced-token',
    ],
    python_requires='>=3.6',
    
)